<?php

namespace Litecms\PackagePlan\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\PackagePlan\Http\Requests\PackagePlanRequest;
use Litecms\PackagePlan\Interfaces\PackagePlanRepositoryInterface;
use Litecms\PackagePlan\Models\PackagePlan;

/**
 * Resource controller class for package_plan.
 */
class PackagePlanResourceController extends BaseController
{

    /**
     * Initialize package_plan resource controller.
     *
     * @param type PackagePlanRepositoryInterface $package_plan
     *
     * @return null
     */
    public function __construct(PackagePlanRepositoryInterface $package_plan)
    {
        parent::__construct();
        $this->repository = $package_plan;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\PackagePlan\Repositories\Criteria\PackagePlanResourceCriteria::class);
    }

    /**
     * Display a list of package_plan.
     *
     * @return Response
     */
    public function index(PackagePlanRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\PackagePlan\Repositories\Presenter\PackagePlanPresenter::class)
                ->$function();
        }

        $package_plans = $this->repository->paginate();

        return $this->response->title(trans('package_plan::package_plan.names'))
            ->view('package_plan::package_plan.index', true)
            ->data(compact('package_plans'))
            ->output();
    }

    /**
     * Display package_plan.
     *
     * @param Request $request
     * @param Model   $package_plan
     *
     * @return Response
     */
    public function show(PackagePlanRequest $request, PackagePlan $package_plan)
    {

        if ($package_plan->exists) {
            $view = 'package_plan::package_plan.show';
        } else {
            $view = 'package_plan::package_plan.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('package_plan::package_plan.name'))
            ->data(compact('package_plan'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new package_plan.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PackagePlanRequest $request)
    {

        $package_plan = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('package_plan::package_plan.name')) 
            ->view('package_plan::package_plan.create', true) 
            ->data(compact('package_plan'))
            ->output();
    }

    /**
     * Create new package_plan.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PackagePlanRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $package_plan                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('package_plan::package_plan.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('package_plan/package_plan/' . $package_plan->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/package_plan/package_plan'))
                ->redirect();
        }

    }

    /**
     * Show package_plan for editing.
     *
     * @param Request $request
     * @param Model   $package_plan
     *
     * @return Response
     */
    public function edit(PackagePlanRequest $request, PackagePlan $package_plan)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('package_plan::package_plan.name'))
            ->view('package_plan::package_plan.edit', true)
            ->data(compact('package_plan'))
            ->output();
    }

    /**
     * Update the package_plan.
     *
     * @param Request $request
     * @param Model   $package_plan
     *
     * @return Response
     */
    public function update(PackagePlanRequest $request, PackagePlan $package_plan)
    {
        try {
            $attributes = $request->all();

            $package_plan->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('package_plan::package_plan.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('package_plan/package_plan/' . $package_plan->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('package_plan/package_plan/' . $package_plan->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the package_plan.
     *
     * @param Model   $package_plan
     *
     * @return Response
     */
    public function destroy(PackagePlanRequest $request, PackagePlan $package_plan)
    {
        try {

            $package_plan->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('package_plan::package_plan.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('package_plan/package_plan/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('package_plan/package_plan/' . $package_plan->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple package_plan.
     *
     * @param Model   $package_plan
     *
     * @return Response
     */
    public function delete(PackagePlanRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('package_plan::package_plan.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('package_plan/package_plan'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/package_plan/package_plan'))
                ->redirect();
        }

    }

    /**
     * Restore deleted package_plans.
     *
     * @param Model   $package_plan
     *
     * @return Response
     */
    public function restore(PackagePlanRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('package_plan::package_plan.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/package_plan/package_plan'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/package_plan/package_plan/'))
                ->redirect();
        }

    }

}
